@@ -24,9 +24,11 @@
 #define KONQUEST_MAPSCENE_H
 
 
-#include <QSvgRenderer>
-#include <KPixmapCache>
 #include <QGraphicsScene>
+#include <QSvgRenderer>
+
+#include <KImageCache>
+
 #include "mapitems.h"
 #include "../game.h"
 
@@ -45,7 +47,7 @@ class MapScene: public QGraphicsScene
         ~MapScene();
 
         QSvgRenderer  *renderer() const  { return m_renderer; }
-        KPixmapCache  *pixmapCache() const  { return m_pixmapCache; }
+        KImageCache   *imageCache() const  { return m_imageCache; }
         Map           *map()      const  { return m_game->map(); }
 
         void           selectPlanet(Planet *planet);
@@ -61,7 +63,7 @@ class MapScene: public QGraphicsScene
 
     void displayPlanetInfo(Planet *planet);
 
-        void           drawBackground( QPainter * painter, const QRectF & rect );
+        void           drawBackground( QPainter * painter, const QRectF & rect ) override;
 
 
     /**
@@ -96,10 +98,10 @@ class MapScene: public QGraphicsScene
         void           clearMap();
         void           mapUpdate();
 
-    signals:
+    Q_SIGNALS:
         void  planetSelected( Planet * );
 
-    private slots:
+    private:
         void  planetItemSelected (PlanetItem *);
 
 private:
@@ -120,7 +122,7 @@ private:
         Game            *m_game;
 
         QSvgRenderer    *m_renderer;
-        KPixmapCache    *m_pixmapCache;
+        KImageCache     *m_imageCache;
         PlanetItem      *m_selectedPlanetItem;
         PlanetInfoItem  *m_planetInfoItem;
         QVector<PlanetItem*> m_planetItems;
